#include "motor.h"
#include "oled.h"
#include "list_motor.h"

motor_t gm6020_up;
motor_t gm6020_down;
motor_t m3508_frontleft;
motor_t m3508_frontright;
motor_t m3508_backleft;
motor_t m3508_backright;
motor_t m2006;

/****************************************/
/*					PID PARAMETERS							*/
/****************************************/

const pid_struct_t M3508_pid_speed = {
		1, 2, 0.005, 2, 16000, 16000
	};
const pid_struct_t M3508_pid_pos = {
		0, 0.1, 0.005, 0, 16000, 16000
	};

const pid_struct_t GM6020_pid_speed = {
		1, 40, 10, 0, 30000, 30000
	};
const pid_struct_t GM6020_pid_pos = {
		0, 12, 3, 5, 10000, 10000
	};

const pid_struct_t M2006_pid_speed = {
		1, 1.5, 0.1, 0, 16384, 16384
	};

const pid_struct_t M2006_pid_pos = {
		0, 12, 3, 5, 10000, 10000
	};


/****************************************/
/*				MOTORS INITIALISATION					*/
/****************************************/
void motors_init(motor_t *motor, int16_t motor_rx_id, enum motors mtr){
	
	switch (mtr){
		case GM6020:
			motor->type = GM6020 ;
			motor->pid_pos = GM6020_pid_pos;
			motor->pid_speed = GM6020_pid_speed;
			motor->can_info.tx_id = 1;
			break;
		case M3508:
			motor->type = M3508 ;
			motor->pid_pos = M3508_pid_pos;
			motor->pid_speed = M3508_pid_speed;
			motor->can_info.tx_id = 0;
			break;
		case M2006:
			motor->type = M2006 ;
			motor->pid_pos = M2006_pid_pos;
			motor->pid_speed = M2006_pid_speed;
			motor->can_info.tx_id = 1;
			break;
		default :
			break;
	}
	motor->can_info.can_id = 0;
	motor->can_info.rx_id = motor_rx_id ;
}


void motors_all_init(void){
	motors_init(&m2006,  0x207, M2006);
	motors_init(&gm6020_down,  0x206, GM6020);
	motors_init(&gm6020_up,  0x205, GM6020);
	motors_init(&m3508_frontleft,  0x201, M3508);
	motors_init(&m3508_frontright,  0x202, M3508);
	motors_init(&m3508_backright,  0x203, M3508);
	motors_init(&m3508_backleft,  0x204, M3508);
	
	switch (ROBOT_ID){
		case 1: 	// Param�tres StandardMeca
			gm6020_up.MIN_POSITION = 7000;
			gm6020_up.MAX_POSITION = 8000;
			gm6020_up.target = 7450;
			gm6020_down.MIN_POSITION = -1300;
			gm6020_down.MAX_POSITION = 2740;
			gm6020_down.target = 660; 
			break;
		
		case 2: 	// Param�tres ICRA
			gm6020_up.MIN_POSITION = 5565;
			gm6020_up.MAX_POSITION = 6675;
			gm6020_up.target = 6200;
			gm6020_down.MIN_POSITION = 2519;
			gm6020_down.MAX_POSITION = 7015;
			gm6020_down.target = 4750; 
			break;
	}
}


